import { logVerbose } from '../../../../core/loggin/index.js';
import * as puppeteer from 'puppeteer';
import { normalize } from 'path';
import { startFlow } from 'lighthouse';
import { UserFlowMock } from './user-flow.mock.js';
import { detectCliMode } from '../../../../global/cli-mode/cli-mode.js';
import { getLhConfigFromArgv, mergeLhConfig } from '../config/index.js';
export async function collectFlow(cliOption, userFlowProvider, argv) {
    let { path, flowOptions, interactions, launchOptions } = userFlowProvider;
    let globalLhCfg = getLhConfigFromArgv(cliOption);
    const lhConfig = mergeLhConfig(globalLhCfg, flowOptions?.config);
    flowOptions.config = lhConfig;
    const browser = await puppeteer.launch(parseLaunchOptions(launchOptions));
    const page = await browser.newPage();
    logVerbose(`Collect: ${flowOptions.name} from URL ${cliOption.url}`);
    logVerbose(`User-flow path: ${normalize(path)}`);
    let start = Date.now();
    const flow = !argv.dryRun ? await startFlow(page, flowOptions) : new UserFlowMock(page, flowOptions);
    // run custom interactions
    await interactions({ flow, page, browser, collectOptions: cliOption });
    logVerbose(`Duration: ${flowOptions.name}: ${(Date.now() - start) / 1000}`);
    await browser.close();
    return flow;
}
function parseLaunchOptions(launchOptions) {
    // object containing the options for puppeteer/chromium
    launchOptions = launchOptions || {
        // has to be false to run in the CI because of a bug :(
        // https://github.com/puppeteer/puppeteer/issues/8148
        headless: false,
        // hack for dryRun => should get fixed inside user flow in future
        defaultViewport: { isMobile: true, isLandscape: false, width: 800, height: 600 }
    };
    const cliMode = detectCliMode();
    // cli mode is "CI" or "SANDBOX"
    if (cliMode !== 'DEFAULT' && launchOptions) {
        const headlessMode = 'new';
        logVerbose(`Set options#headless to ${headlessMode} in puppeteer#launch as we are running in ${cliMode} mode`);
        launchOptions.headless = headlessMode;
    }
    return launchOptions;
}
//# sourceMappingURL=collect-flow.js.map