import { join } from 'node:path';
import { existsSync, lstatSync, readdirSync } from 'node:fs';
import { resolveAnyFile } from '../../../../core/file/index.js';
export async function loadFlow(collect) {
    const { ufPath } = collect;
    const path = join(ufPath);
    if (!existsSync(path)) {
        throw new Error(`ufPath: ${path} is neither a file nor a directory`);
    }
    let files;
    if (lstatSync(path).isDirectory()) {
        files = readdirSync(path).map(file => join(path, file));
    }
    else {
        files = [path];
    }
    const flows = await Promise.all(files.filter(f => f.endsWith('js') || f.endsWith('ts'))
        .map((file) => resolveAnyFile(file)));
    if (flows.length === 0) {
        // @TODO use const for error msg
        throw new Error(`No user flows found in ${ufPath}`);
    }
    return flows;
}
//# sourceMappingURL=load-flow.js.map