import Enquirer from 'enquirer';
import { get as interactive } from '../../../global/options/interactive.js';
import { ERROR_PERSIST_FORMAT_REQUIRED, ERROR_PERSIST_FORMAT_WRONG, PROMPT_PERSIST_FORMAT } from '../../collect/options/format.constant.js';
import { applyValidations, hasError, VALIDATORS } from '../../../core/validation/index.js';
import { REPORT_FORMAT_NAMES, REPORT_FORMAT_OPTIONS, REPORT_FORMAT_VALUES } from '../../collect/constants.js';
import { getEnvPreset } from '../../../pre-set.js';
export async function setupFormat(config) {
    let format = Array.isArray(config?.persist?.format) ? config.persist.format : [];
    if (interactive()) {
        const { f } = format.length ? { f: format } : await Enquirer.prompt([
            {
                type: 'multiselect',
                name: 'f',
                message: PROMPT_PERSIST_FORMAT,
                choices: REPORT_FORMAT_OPTIONS,
                initial: REPORT_FORMAT_VALUES.indexOf(getEnvPreset().format[0]),
                // @NOTICE typing is broken here
                result(value) {
                    const values = value;
                    return values.map((name) => REPORT_FORMAT_VALUES[REPORT_FORMAT_NAMES.indexOf(name)]);
                },
                multiple: true
            }
        ]);
        format = f || [];
        if (format?.length === 0) {
            return setupFormat(config);
        }
    }
    // Validate
    const allOf = VALIDATORS.allOf(REPORT_FORMAT_VALUES);
    const errors = applyValidations(format, [
        VALIDATORS.required,
        allOf
    ]);
    if (hasError(errors)) {
        if (errors.required) {
            throw new Error(ERROR_PERSIST_FORMAT_REQUIRED);
        }
        if (errors.allOf) {
            throw new Error(ERROR_PERSIST_FORMAT_WRONG(errors.allOf.value));
        }
    }
    return {
        ...config,
        persist: { ...config?.persist, format }
    };
}
//# sourceMappingURL=format.setup.js.map